/**
 * Module with helper functions to execute Regular Expressions
 */
/**
 * Returns the result of the String.match method against the RegEx:
 * `(?<=((FROM[ \n\r]+)|(JOIN[ \n\r]+)|(APPLY[ \n\r]+)))(${tables.join('|')})`
 *
 * @param query     Query to be tested
 * @param tables    List of database tables
 * @return the result of query.match method
 */
export declare const readingQueryMatch: (query: string, tables: Array<string>) => RegExpMatchArray | null;
/**
 * Returns the result of the String.match method against the RegEx:
 * `^(INSERT INTO).+(?<table>${tables.join('|')})`
 *
 * @param query     Query to be tested
 * @param tables    List of database tables
 * @return the result of query.match method
 */
export declare const writingQueryMatch: (query: string, tables: Array<string>) => RegExpMatchArray | null;
/**
 * Returns the table on which the query was SELECTing data from.
 *
 * @param query     Query to be tested
 * @param tables    List of database tables
 * @return The tables names, or null
 */
export declare const tableFromReadQuery: (query: string, tables: Array<string>) => Array<string> | null;
/**
 * Returns the table on which the query was INSERTing data to.
 *
 * @param query     Query to be tested
 * @param tables    List of database tables
 * @return The table name, or null
 */
export declare const tableFromWritingQuery: (query: string, tables: Array<string>) => string | null;
